@@ -6,11 +6,11 @@ import logging
 
 
 _moduleLogger = logging.getLogger("gonvert")
-sys.path.append("/usr/lib/gonvert/")
+sys.path.append("/opt/gonvert/lib")
 
 
 import constants
-import gonvert_glade
+import gonvert_qt
 
 
 try:
@@ -21,6 +21,9 @@ except OSError, e:
 
 logging.basicConfig(level=logging.DEBUG, filename=constants._user_logpath_)
 _moduleLogger.info("gonvert %s-%s" % (constants.__version__, constants.__build__))
+_moduleLogger.info("OS: %s" % (os.uname()[0], ))
+_moduleLogger.info("Kernel: %s (%s) for %s" % os.uname()[2:])
+_moduleLogger.info("Hostname: %s" % os.uname()[1])
 
 
-gonvert_glade.run_gonvert()
+gonvert_qt.run_gonvert()
